pub struct Transaction {Show 26 fields
pub id: TransactionId,
pub relayer_id: RelayerId,
pub to: EvmAddress,
pub from: EvmAddress,
pub value: TransactionValue,
pub data: TransactionData,
pub nonce: TransactionNonce,
pub chain_id: ChainId,
pub gas_limit: Option<GasLimit>,
pub status: TransactionStatus,
pub blobs: Option<Vec<TransactionBlob>>,
pub known_transaction_hash: Option<TransactionHash>,
pub queued_at: DateTime<Utc>,
pub expires_at: DateTime<Utc>,
pub sent_at: Option<DateTime<Utc>>,
pub confirmed_at: Option<DateTime<Utc>>,
pub sent_with_gas: Option<GasPriceResult>,
pub sent_with_blob_gas: Option<BlobGasPriceResult>,
pub mined_at: Option<DateTime<Utc>>,
pub mined_at_block_number: Option<BlockNumber>,
pub speed: TransactionSpeed,
pub sent_with_max_priority_fee_per_gas: Option<MaxPriorityFee>,
pub sent_with_max_fee_per_gas: Option<MaxFee>,
pub is_noop: bool,
pub external_id: Option<String>,
pub cancelled_by_transaction_id: Option<TransactionId>,
}Fields
id: TransactionIdrelayer_id: RelayerIdto: EvmAddressfrom: EvmAddressvalue: TransactionValuedata: TransactionDatanonce: TransactionNoncechain_id: ChainIdgas_limit: Option<GasLimit>status: TransactionStatusblobs: Option<Vec<TransactionBlob>>known_transaction_hash: Option<TransactionHash>queued_at: DateTime<Utc>expires_at: DateTime<Utc>sent_at: Option<DateTime<Utc>>confirmed_at: Option<DateTime<Utc>>sent_with_gas: Option<GasPriceResult>sent_with_blob_gas: Option<BlobGasPriceResult>mined_at: Option<DateTime<Utc>>mined_at_block_number: Option<BlockNumber>speed: TransactionSpeedsent_with_max_priority_fee_per_gas: Option<MaxPriorityFee>sent_with_max_fee_per_gas: Option<MaxFee>is_noop: boolexternal_id: Option<String>cancelled_by_transaction_id: Option<TransactionId>Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub fn has_been_sent_before(&self) -> bool
pub fn has_been_sent_before(&self) -> bool
Checks if this transaction has been previously sent to the network.
Returns
bool- True if the transaction has a sent_at timestamp
Sourcepub fn to_eip1559_typed_transaction(
&self,
override_gas_price: Option<&GasPriceResult>,
) -> Result<EthereumTypedTransaction<TxEip4844Variant>, TransactionConversionError>
pub fn to_eip1559_typed_transaction( &self, override_gas_price: Option<&GasPriceResult>, ) -> Result<EthereumTypedTransaction<TxEip4844Variant>, TransactionConversionError>
Converts this transaction to an EIP-1559 typed transaction.
Creates an EIP-1559 transaction with max priority fee and max fee per gas.
Arguments
override_gas_price- Optional gas price to override stored valuesoverride_gas_limit- Optional gas limit to override stored values
Returns
Ok(TypedTransaction)- EIP-1559 typed transactionErr(TransactionConversionError)- If gas price information is missing
Sourcepub fn to_eip1559_typed_transaction_with_gas_limit(
&self,
override_gas_price: Option<&GasPriceResult>,
override_gas_limit: Option<GasLimit>,
) -> Result<EthereumTypedTransaction<TxEip4844Variant>, TransactionConversionError>
pub fn to_eip1559_typed_transaction_with_gas_limit( &self, override_gas_price: Option<&GasPriceResult>, override_gas_limit: Option<GasLimit>, ) -> Result<EthereumTypedTransaction<TxEip4844Variant>, TransactionConversionError>
Converts this transaction to an EIP-1559 typed transaction with optional gas limit override.
Creates an EIP-1559 transaction with max priority fee and max fee per gas.
Arguments
override_gas_price- Optional gas price to override stored valuesoverride_gas_limit- Optional gas limit to override stored values
Returns
Ok(TypedTransaction)- EIP-1559 typed transactionErr(TransactionConversionError)- If gas price or gas limit information is missing
pub fn to_legacy_typed_transaction( &self, override_gas_price: Option<&GasPriceResult>, ) -> Result<EthereumTypedTransaction<TxEip4844Variant>, TransactionConversionError>
pub fn to_legacy_typed_transaction_with_gas_limit( &self, override_gas_price: Option<&GasPriceResult>, override_gas_limit: Option<GasLimit>, ) -> Result<EthereumTypedTransaction<TxEip4844Variant>, TransactionConversionError>
pub fn to_blob_typed_transaction( &self, override_gas_price: Option<&GasPriceResult>, override_blob_gas_price: Option<&BlobGasPriceResult>, ) -> Result<EthereumTypedTransaction<TxEip4844Variant>, TransactionConversionError>
pub fn to_blob_typed_transaction_with_gas_limit( &self, override_gas_price: Option<&GasPriceResult>, override_blob_gas_price: Option<&BlobGasPriceResult>, override_gas_limit: Option<GasLimit>, ) -> Result<EthereumTypedTransaction<TxEip4844Variant>, TransactionConversionError>
Sourcepub fn is_blob_transaction(&self) -> bool
pub fn is_blob_transaction(&self) -> bool
Checks if this is a blob transaction (EIP-4844).
Returns
bool- True if the transaction has blob data